==> ejc-businessplan-impl-3.0.0-20220329.134247-55-sources.jar: com/ejianc/business/busniessplan/vo/FundsplanningdetailVO.java <==
package com.ejianc.business.busniessplan.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 项目资金管理策划子表
 * 
 * @author generator
 * 
 */
public class FundsplanningdetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.String sort; // 序号
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date collectbranchTime; // 收支时间(日期)
    private java.lang.String collectbranchTimeShow; // 收支时间(日期)
    private java.lang.String imagenode; // 形象进度节点情况
    private java.math.BigDecimal plancomplete; // 计划完成产值
    private java.math.BigDecimal civilengineering; // 土建
    private java.math.BigDecimal installation; // 安装
    private java.math.BigDecimal other; // 其它
    private java.math.BigDecimal labourservices; // 劳务
    private java.math.BigDecimal material; // 材料
    private java.math.BigDecimal professional; // 专业分包
    private java.math.BigDecimal othercost; // 其它费用
    private java.math.BigDecimal current; // 当期
    private java.math.BigDecimal cumulative; // 累计
    private java.math.BigDecimal answer; // 应对措施
    private java.lang.String remarks; // 备注
    private java.math.BigDecimal salary; // 工资
    private java.lang.String cioAmount;//合计
    private java.lang.String errorMsg;

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public String getCioAmount() {
        return cioAmount;
    }

    public void setCioAmount(String cioAmount) {
        this.cioAmount = cioAmount;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 收支时间(日期)
     */
    public java.util.Date getCollectbranchTime() {
        return collectbranchTime;
    }

    /**
     * 收支时间(日期)
     */
    public void setCollectbranchTime(java.util.Date collectbranchTime) {
        this.collectbranchTime = collectbranchTime;
    }
    /**
     * 形象进度节点情况
     */
    public java.lang.String getImagenode() {
        return imagenode;
    }

    /**
     * 形象进度节点情况
     */
    public void setImagenode(java.lang.String imagenode) {
        this.imagenode = imagenode;
    }
    /**
     * 计划完成产值
     */
    public java.math.BigDecimal getPlancomplete() {
        return plancomplete;
    }

    /**
     * 计划完成产值
     */
    public void setPlancomplete(java.math.BigDecimal plancomplete) {
        this.plancomplete = plancomplete;
    }
    /**
     * 土建
     */
    public java.math.BigDecimal getCivilengineering() {
        return civilengineering;
    }

    /**
     * 土建
     */
    public void setCivilengineering(java.math.BigDecimal civilengineering) {
        this.civilengineering = civilengineering;
    }
    /**
     * 安装
     */
    public java.math.BigDecimal getInstallation() {
        return installation;
    }

    /**
     * 安装
     */
    public void setInstallation(java.math.BigDecimal installation) {
        this.installation = installation;
    }
    /**
     * 其它
     */
    public java.math.BigDecimal getOther() {
        return other;
    }

    /**
     * 其它
     */
    public void setOther(java.math.BigDecimal other) {
        this.other = other;
    }
    /**
     * 劳务
     */
    public java.math.BigDecimal getLabourservices() {
        return labourservices;
    }

    /**
     * 劳务
     */
    public void setLabourservices(java.math.BigDecimal labourservices) {
        this.labourservices = labourservices;
    }
    /**
     * 材料
     */
    public java.math.BigDecimal getMaterial() {
        return material;
    }

    /**
     * 材料
     */
    public void setMaterial(java.math.BigDecimal material) {
        this.material = material;
    }
    /**
     * 专业分包
     */
    public java.math.BigDecimal getProfessional() {
        return professional;
    }

    /**
     * 专业分包
     */
    public void setProfessional(java.math.BigDecimal professional) {
        this.professional = professional;
    }
    /**
     * 其它费用
     */
    public java.math.BigDecimal getOthercost() {
        return othercost;
    }

    /**
     * 其它费用
     */
    public void setOthercost(java.math.BigDecimal othercost) {
        this.othercost = othercost;
    }
    /**
     * 当期
     */
    public java.math.BigDecimal getCurrent() {
        return current;
    }

    /**
     * 当期
     */
    public void setCurrent(java.math.BigDecimal current) {
        this.current = current;
    }
    /**
     * 累计
     */
    public java.math.BigDecimal getCumulative() {
        return cumulative;
    }

    /**
     * 累计
     */
    public void setCumulative(java.math.BigDecimal cumulative) {
        this.cumulative = cumulative;
    }
    /**
     * 应对措施
     */
    public java.math.BigDecimal getAnswer() {
        return answer;
    }

    /**
     * 应对措施
     */
    public void setAnswer(java.math.BigDecimal answer) {
        this.answer = answer;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 工资
     */
    public java.math.BigDecimal getSalary() {
        return salary;
    }

    /**
     * 工资
     */
    public void setSalary(java.math.BigDecimal salary) {
        this.salary = salary;
    }
    public String getCollectbranchTimeShow() {
        return collectbranchTimeShow;
    }

    public void setCollectbranchTimeShow(String collectbranchTimeShow) {
        this.collectbranchTimeShow = collectbranchTimeShow;
    }
    
}

==> ejc-businessplan-impl-3.0.0-20220701.033305-89-sources.jar: com/ejianc/business/busniessplan/vo/FundsplanningdetailVO.java <==
package com.ejianc.business.busniessplan.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 项目资金管理策划子表
 * 
 * @author generator
 * 
 */
public class FundsplanningdetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.String sort; // 序号
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM", timezone = "GMT+8")
    private java.util.Date collectbranchTime; // 收支时间(日期)
    private java.lang.String collectbranchTimeShow; // 收支时间(日期)
    private java.lang.String imagenode; // 形象进度节点情况
    private java.math.BigDecimal plancomplete; // 计划完成产值
    private java.math.BigDecimal civilengineering; // 土建
    private java.math.BigDecimal installation; // 安装
    private java.math.BigDecimal other; // 其它
    private java.math.BigDecimal labourservices; // 劳务
    private java.math.BigDecimal material; // 材料
    private java.math.BigDecimal professional; // 专业分包
    private java.math.BigDecimal othercost; // 其它费用
    private java.math.BigDecimal current; // 当期
    private java.math.BigDecimal cumulative; // 累计
    private java.math.BigDecimal answer; // 应对措施
    private java.lang.String remarks; // 备注
    private java.math.BigDecimal salary; // 工资
    private java.lang.String cioAmount;//合计
    private java.lang.String errorMsg;

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public String getCioAmount() {
        return cioAmount;
    }

    public void setCioAmount(String cioAmount) {
        this.cioAmount = cioAmount;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 收支时间(日期)
     */
    public java.util.Date getCollectbranchTime() {
        return collectbranchTime;
    }

    /**
     * 收支时间(日期)
     */
    public void setCollectbranchTime(java.util.Date collectbranchTime) {
        this.collectbranchTime = collectbranchTime;
    }
    /**
     * 形象进度节点情况
     */
    public java.lang.String getImagenode() {
        return imagenode;
    }

    /**
     * 形象进度节点情况
     */
    public void setImagenode(java.lang.String imagenode) {
        this.imagenode = imagenode;
    }
    /**
     * 计划完成产值
     */
    public java.math.BigDecimal getPlancomplete() {
        return plancomplete;
    }

    /**
     * 计划完成产值
     */
    public void setPlancomplete(java.math.BigDecimal plancomplete) {
        this.plancomplete = plancomplete;
    }
    /**
     * 土建
     */
    public java.math.BigDecimal getCivilengineering() {
        return civilengineering;
    }

    /**
     * 土建
     */
    public void setCivilengineering(java.math.BigDecimal civilengineering) {
        this.civilengineering = civilengineering;
    }
    /**
     * 安装
     */
    public java.math.BigDecimal getInstallation() {
        return installation;
    }

    /**
     * 安装
     */
    public void setInstallation(java.math.BigDecimal installation) {
        this.installation = installation;
    }
    /**
     * 其它
     */
    public java.math.BigDecimal getOther() {
        return other;
    }

    /**
     * 其它
     */
    public void setOther(java.math.BigDecimal other) {
        this.other = other;
    }
    /**
     * 劳务
     */
    public java.math.BigDecimal getLabourservices() {
        return labourservices;
    }

    /**
     * 劳务
     */
    public void setLabourservices(java.math.BigDecimal labourservices) {
        this.labourservices = labourservices;
    }
    /**
     * 材料
     */
    public java.math.BigDecimal getMaterial() {
        return material;
    }

    /**
     * 材料
     */
    public void setMaterial(java.math.BigDecimal material) {
        this.material = material;
    }
    /**
     * 专业分包
     */
    public java.math.BigDecimal getProfessional() {
        return professional;
    }

    /**
     * 专业分包
     */
    public void setProfessional(java.math.BigDecimal professional) {
        this.professional = professional;
    }
    /**
     * 其它费用
     */
    public java.math.BigDecimal getOthercost() {
        return othercost;
    }

    /**
     * 其它费用
     */
    public void setOthercost(java.math.BigDecimal othercost) {
        this.othercost = othercost;
    }
    /**
     * 当期
     */
    public java.math.BigDecimal getCurrent() {
        return current;
    }

    /**
     * 当期
     */
    public void setCurrent(java.math.BigDecimal current) {
        this.current = current;
    }
    /**
     * 累计
     */
    public java.math.BigDecimal getCumulative() {
        return cumulative;
    }

    /**
     * 累计
     */
    public void setCumulative(java.math.BigDecimal cumulative) {
        this.cumulative = cumulative;
    }
    /**
     * 应对措施
     */
    public java.math.BigDecimal getAnswer() {
        return answer;
    }

    /**
     * 应对措施
     */
    public void setAnswer(java.math.BigDecimal answer) {
        this.answer = answer;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 工资
     */
    public java.math.BigDecimal getSalary() {
        return salary;
    }

    /**
     * 工资
     */
    public void setSalary(java.math.BigDecimal salary) {
        this.salary = salary;
    }
    public String getCollectbranchTimeShow() {
        return collectbranchTimeShow;
    }

    public void setCollectbranchTimeShow(String collectbranchTimeShow) {
        this.collectbranchTimeShow = collectbranchTimeShow;
    }
    
}
